%define	lib_major	4
%define	lib_name	%mklibname %{name} %{lib_major}
%define develname	%mklibname -d %{name}

Summary:	PARI/GP - Number Theory-oriented Computer Algebra System
Name:		pari
Version:	2.7.2
Release:	%mkrel 4
License:	GPL
Group:		Sciences/Mathematics
Source0:	http://pari.math.u-bordeaux.fr/pub/pari/unix/%{name}-%{version}.tar.gz
Source1:	http://pari.math.u-bordeaux.fr/pub/pari/packages/elldata.tgz
Source2:	http://pari.math.u-bordeaux.fr/pub/pari/packages/galdata.tgz
Source3:	http://pari.math.u-bordeaux.fr/pub/pari/packages/seadata.tgz
Source4:	http://pari.math.u-bordeaux.fr/pub/pari/packages/nftables.tgz
Source5:	http://pari.math.u-bordeaux.fr/pub/pari/packages/galpol.tgz
URL:		http://pari.math.u-bordeaux.fr/
Patch0:		pari-arch.patch
Patch2:		pari-gphelp.patch
Patch3:		pari-runpath.patch
Patch4:		perl-warning-non-fatal.patch

BuildRequires:	perl-devel
BuildRequires:	libgmp-devel
BuildRequires:	libx11-devel
BuildRequires:	readline-devel
BuildRequires:	ncurses-devel
BuildRequires:	texlive
BuildRequires:	texlive-texmf
BuildRequires:	emacs
Requires:	perl
Requires:	xdg-utils
Recommends:	%{name}-data = %{version}-%{release}

%description
PARI/GP is a widely used computer algebra system designed for fast
computations in number theory (factorizations, algebraic number theory,
elliptic curves...), but also contains a large number of other useful
functions to compute with mathematical entities such as matrices,
polynomials, power series, algebraic numbers, etc., and a lot of
transcendental functions. PARI is also available as a C library to allow
for faster computations.

%package	data
Group:		Sciences/Mathematics
Summary:	Optional pari data packages
Requires:	%{name} = %{version}-%{release}
BuildArch:	noarch

%description	data
  elldata is PARI/GP version of J. E. Cremona Elliptic Curve Data,
needed by ellsearch and ellidentify.
  galdata is needed by polgalois to compute Galois group in degrees
8 through 11.
  seadata is needed by ellap for large primes.
  nftables is a repackaging of the historical megrez number field
tables (errors fixed, 1/10th the size, easier to use).

%package -n	%{lib_name}
Group:		System/Libraries
Summary:	Shared PARI library

%description -n %{lib_name}
This package contains the libraries needed to run pari.

%package -n	%{develname}
Group:		System/Libraries
Summary:	Development files for PARI shared library
Requires:	%{lib_name} = %{version}-%{release}
Obsoletes:	%{_lib}pari2-devel < 2.5
Provides:	%{name}-devel = %{version}-%{release}
Provides:	lib%{name}-devel = %{version}-%{release}

%description -n %{develname}
This package contains the header files needed to develop
applications using pari.

%prep
%setup -q -a1 -a2 -a3 -a4 -a5
mv -f nftables data
%autopatch -p1

%build
%define pkgdocdir	%{_docdir}/%{name}
%define pkgdatadir	%{_datadir}/%{name}-%{version}
%setup_compile_flags

# Using --libdir to properly link with newer interface
# Using --disable-tls for safety due to other packages linked to pari
sh Configure						\
	--prefix=%{_prefix}				\
	--includedir=%{_includedir}			\
	--datadir=%{pkgdatadir}/data			\
	--sysdatadir=%{_libdir}/%{name}			\
	--share-prefix=%{_datadir}			\
	--host=%{_arch}-%{_os}				\
	--graphic=X11					\
	--with-gmp					\
	--libdir=%{buildroot}%{_libdir}			\
	--disable-tls

echo "echo %_build_arch-%_build_os" > config/arch-osname

%ifarch %arm
make gp
%else
make bench
%endif

make doc

%install
# pari, libpari & libpari-devel
%makeinstall_std					\
	READMEDIR='$(DESTDIR)'%{pkgdocdir}		\
	LIBDIR='$(DESTDIR)'%{_libdir}			\
	DOCDIR='$(DESTDIR)'%{pkgdocdir}

# Install global configuration file.
mkdir %{buildroot}%{_sysconfdir}
# Add some more reasonable "commented" sample configurations
sed	-e 's@/usr/local/@%{_prefix}/@'				\
	-e 's@path =.*@path = "%{pkgdatadir}:.:~/gpdir"@'	\
	-e 's@lib/gpalias@misc/gpalias@'			\
	misc/gprc.dft > %{buildroot}/%{_sysconfdir}/gprc

# don't need to install this file...
rm -f %{buildroot}%{pkgdocdir}/*.{dvi,tex}
rm -f %{buildroot}%{pkgdocdir}/translations

# gphelp wants docs in %{pkgdatadir}/data/doc (removing the /data/ requirement)
ln -sf %{pkgdocdir} %{buildroot}%{pkgdatadir}/doc
perl -pi -e 's@%{pkgdatadir}/data@%{pkgdatadir}@;'		\
	%{buildroot}/%{_bindir}/gphelp

%files
%config(noreplace) %attr(644,root,root) %{_sysconfdir}/gprc
%{_bindir}/gp-*
%{_bindir}/gp
%{_bindir}/gphelp
%{_bindir}/tex2mail
%{_mandir}/man1/[^g]*.1*
%{_mandir}/man1/gp.1*
%{_mandir}/man1/gp-*.1*
%{_mandir}/man1/gphelp.1*
%doc AUTHORS CHANGES COMPAT MACHINES README
%dir %{pkgdatadir}
%{pkgdatadir}/doc
%doc %{pkgdocdir}/refcard.ps

%files	data
%dir %{pkgdatadir}/data
%{pkgdatadir}/data/*

%files	-n %{lib_name}
%{_libdir}/*.so.%{version}
%{_libdir}/*.so.%{lib_major}

%files	-n %{develname}
%{_includedir}/%{name}
%{_libdir}/*.so
%{_libdir}/%{name}/


%changelog
* Sun Apr 03 2016 pterjan <pterjan> 2.7.2-4.mga6
+ Revision: 997787
- Update file list
- Better arm workaround
- Add a Debian patch fixing the generation of doc and workaround a problem on arm

  + umeabot <umeabot>
    - Mageia 6 Mass Rebuild

  + neoclust <neoclust>
    - Rebuild to make availaable on ARM

* Thu Oct 16 2014 akien <akien> 2.7.2-1.mga5
+ Revision: 763882
- Version 2.7.2

* Wed Oct 15 2014 umeabot <umeabot> 2.7.1-3.mga5
+ Revision: 740261
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild

  + tv <tv>
    - s/uggests:/Recommends:/

* Sat Aug 16 2014 akien <akien> 2.7.1-1.mga5
+ Revision: 663870
- Version 2.7.1
- Updated elldata tarball and added galpol tarball

* Sun Jun 15 2014 luigiwalser <luigiwalser> 2.5.3-5.mga5
+ Revision: 636553
- update texlive BRs

* Sun Jan 13 2013 umeabot <umeabot> 2.5.3-4.mga3
+ Revision: 362405
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Oct 08 2012 fwang <fwang> 2.5.3-3.mga3
+ Revision: 303349
- main binary should require data

* Mon Oct 08 2012 fwang <fwang> 2.5.3-2.mga3
+ Revision: 303320
- put config file into shorter dir

* Mon Oct 08 2012 fwang <fwang> 2.5.3-1.mga3
+ Revision: 303300
- update file list
- update file list
- about to split gp2c
- drop old patch
- new version 2.5.3

* Fri Sep 02 2011 tv <tv> 2.4.3.alpha-2.mga2
+ Revision: 137827
- make the huge data subpackage be noarch

* Fri Feb 25 2011 dmorgan <dmorgan> 2.4.3.alpha-1.mga1
+ Revision: 59921
- Remove mdv macros
- imported package pari


* Thu Nov 11 2010 Paulo Andrade <pcpa@mandriva.com.br> 2.4.3.alpha-1mdv2011.0
+ Revision: 595897
- Update to pari 2.4.3-alpha

* Tue Jul 27 2010 Paulo Andrade <pcpa@mandriva.com.br> 2.3.5-8mdv2011.0
+ Revision: 560893
- Use xdg-open in gphelp instead of xdvi

* Wed Feb 10 2010 Funda Wang <fwang@mandriva.org> 2.3.5-7mdv2010.1
+ Revision: 503562
- New version 2.3.5

* Wed Feb 10 2010 Funda Wang <fwang@mandriva.org> 2.3.4-6mdv2010.1
+ Revision: 503558
- rebuild for new gmp

* Wed Feb 03 2010 Paulo Andrade <pcpa@mandriva.com.br> 2.3.4-5mdv2010.1
+ Revision: 499828
- Update to gpc-0.0.5pl9
- Change from requires to suggests of xdvi

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild

* Wed Feb 25 2009 Guillaume Rousse <guillomovitch@mandriva.org> 2.3.4-3mdv2009.1
+ Revision: 344843
- rebuild against new readline

* Fri Feb 20 2009 Paulo Andrade <pcpa@mandriva.com.br> 2.3.4-2mdv2009.1
+ Revision: 343068
- Use gmp instead of builtin math library.
  gmp is significantly faster for calculations with large numbers.
  Correct gphelp, that was expecting to find documentation outside
  %%{_docdir}.
  xdvi is now required, as it is used to view documentation.
  xdvi cannot be installed due to bug #48029; as an alternative, temporary
  solution, it is possible to either use patch in #38016, or set the
  GPXDVI environment variable (a good option is the okular program).

* Wed Feb 18 2009 Paulo Andrade <pcpa@mandriva.com.br> 2.3.4-1mdv2009.1
+ Revision: 342731
- Update to latest upstream release, version 2.3.4
  o gp2c updated to 0.0.5pl7.
  o Corrected spec bug that set pari version to gp2c one.
  o Added extra optional pari data packages to the -data rpm.
  o Added missing BuildRequires and Requires.

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - parallel build is broken
    - BuildRequires tetex tetex-dvips
    - rebuild
    - kill re-definition of %%buildroot on Pixel's request

  + Pixel <pixel@mandriva.com>
    - do not call ldconfig in %%post/%%postun, it is now handled by filetriggers

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot


* Mon Aug 14 2006 Olivier Thauvin <nanardon@mandriva.org>
+ 08/14/06 21:09:04 (56078)
- rebuild
- use our optflags
- cleanup

* Mon Aug 14 2006 Olivier Thauvin <nanardon@mandriva.org>
+ 08/14/06 20:51:28 (56075)
Import pari

* Fri Jan 06 2006 Nicolas Lcureuil <neoclust@mandriva.org> 2.1.7-2mdk
- Add BuildRequires

* Wed Jan 04 2006 Nicolas Lcureuil <neoclust@mandriva.org> 2.1.7-1mdk
- New release 2.1.7 (pari) 
- New release 0.0.4pl3 (gp2c)

* Fri Sep 30 2005 Nicolas Lcureuil <neoclust@mandriva.org> 2.1.6-3mdk
- buildrequires

* Mon Apr 25 2005 Giuseppe Ghib <ghibo@mandriva.com> 2.1.6-2mdk
- Fixed %%install stage for X86-64.

* Sun Jan 23 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 2.1.6-1mdk
- 2.1.6
- update gp2c to 0.0.3pl4
- proper use of %%mklibname

* Sat Jan 22 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 2.1.5-3mdk
- bah, don't use different release tag for subpackage

* Sat Jan 22 2005 Per Øyvind Karlsen <peroyvind@linux-mandrake.com> 2.1.5-2mdk
- rebuild for new readline

* Fri Nov 07 2003 Arnaud de Lorbeau <adelorbeau@mandrakesoft.com> 2.1.5-1mdk
- New release and first Mandrake package
- Modify the Configure file to use -O2 instead of -O3
- Add libs and a devel package
- Add gp2c to the same srpm

